diff --git a/pgadmin/ctl/calbox.cpp b/pgadmin/ctl/calbox.cpp
index be26322..930de60 100644
--- a/pgadmin/ctl/calbox.cpp
+++ b/pgadmin/ctl/calbox.cpp
@@ -15,6 +15,8 @@
 
 #include "ctl/calbox.h"
 
+#if !defined(wxUSE_DATEPICKCTRL) || !wxUSE_DATEPICKCTRL
+
 #if defined(__WXMSW__)
 #define TXTCTRL_FLAGS     wxNO_BORDER
 #define CALBORDER         0
@@ -513,3 +515,5 @@ void wxCalendarBox::OnCalKey(wxKeyEvent &ev)
 	else
 		ev.Skip();
 }
+
+#endif // !defined(wxUSE_DATEPICKCTRL) || !wxUSE_DATEPICKCTRL
diff --git a/pgadmin/ctl/xh_calb.cpp b/pgadmin/ctl/xh_calb.cpp
index 4563be2..08a46ad 100644
--- a/pgadmin/ctl/xh_calb.cpp
+++ b/pgadmin/ctl/xh_calb.cpp
@@ -21,6 +21,15 @@ IMPLEMENT_DYNAMIC_CLASS(wxCalendarBoxXmlHandler, wxXmlResourceHandler)
 wxCalendarBoxXmlHandler::wxCalendarBoxXmlHandler()
 	: wxXmlResourceHandler()
 {
+	/*
+	 * Only available with the wxDatePickerCtrl
+	 */
+	XRC_ADD_STYLE(wxDP_DEFAULT);
+	XRC_ADD_STYLE(wxDP_SPIN);
+	XRC_ADD_STYLE(wxDP_DROPDOWN);
+	XRC_ADD_STYLE(wxDP_ALLOWNONE);
+	XRC_ADD_STYLE(wxDP_SHOWCENTURY);
+
 	AddWindowStyles();
 }
 
@@ -38,14 +47,24 @@ wxObject *wxCalendarBoxXmlHandler::DoCreateResource()
 	                 wxDefaultValidator,
 	                 GetName());
 
-#else
+#else // pgUSE_WX_CAL
+#if !defined(wxUSE_DATEPICKCTRL) || !wxUSE_DATEPICKCTRL
 	calendar->Create(m_parentAsWindow,
 	                 GetID(),
 	                 wxDefaultDateTime,
 	                 GetPosition(), GetSize(),
 	                 GetStyle(),
 	                 GetName());
-#endif
+#else // !defined(wxUSE_DATEPICKCTRL) || !wxUSE_DATEPICKCTRL
+	calendar->Create(m_parentAsWindow,
+	                 (wxWindowID)GetID(),
+	                 wxDefaultDateTime,
+	                 GetPosition(), GetSize(),
+	                 (long int)GetStyle(),
+	                 wxDefaultValidator,
+	                 GetName());
+#endif // !defined(wxUSE_DATEPICKCTRL) || !wxUSE_DATEPICKCTRL
+#endif // pgUSE_WX_CAL
 
 	SetupWindow(calendar);
 
diff --git a/pgadmin/include/ctl/calbox.h b/pgadmin/include/ctl/calbox.h
index 474249b..0658249 100644
--- a/pgadmin/include/ctl/calbox.h
+++ b/pgadmin/include/ctl/calbox.h
@@ -13,6 +13,15 @@
 #define _WX_CALBOX_H_
 
 #include "wx/calctrl.h"
+
+#if defined(wxUSE_DATEPICKCTRL) && wxUSE_DATEPICKCTRL
+#include "wx/datectrl.h"
+#if wxUSE_DATEPICKCTRL_GENERIC
+#include "wx/generic/datectrl.h"
+#endif // wxUSE_DATEPICKCTRL_GENERIC
+typedef wxDatePickerCtrl wxCalendarBox;
+#else
+
 // pgCompatCalendarCtrl is a typedef for either wxGenericCalendarCtrl or wxCalendarCtrl
 #if wxCHECK_VERSION(2, 9, 0)
 #include "wx/generic/calctrlg.h"
@@ -121,5 +130,7 @@ private:
 	DECLARE_NO_COPY_CLASS(wxCalendarBox)
 };
 
+#endif // wxUSE_DATEPICKCTRL
+
 #endif // _WX_CALBOX_H_
 
diff --git a/pgadmin/ui/dlgRole.xrc b/pgadmin/ui/dlgRole.xrc
index 732d7ec..2eac360 100644
--- a/pgadmin/ui/dlgRole.xrc
+++ b/pgadmin/ui/dlgRole.xrc
@@ -134,6 +134,7 @@
                     <growablecols>0</growablecols>
                     <object class="sizeritem">
                       <object class="wxCalendarBox" name="datValidUntil">
+                        <style>wxDP_ALLOWNONE|wxDP_DROPDOWN</style>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
diff --git a/pgadmin/ui/dlgSchedule.xrc b/pgadmin/ui/dlgSchedule.xrc
index e52b851..4110afb 100644
--- a/pgadmin/ui/dlgSchedule.xrc
+++ b/pgadmin/ui/dlgSchedule.xrc
@@ -80,6 +80,7 @@
                     <growablecols>0,1</growablecols>
                     <object class="sizeritem">
                       <object class="wxCalendarBox" name="calStart">
+                        <style>wxDP_ALLOWNONE|wxDP_DROPDOWN</style>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
@@ -109,6 +110,7 @@
                     <growablecols>0,1</growablecols>
                     <object class="sizeritem">
                       <object class="wxCalendarBox" name="calEnd">
+                        <style>wxDP_ALLOWNONE|wxDP_DROPDOWN</style>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
@@ -360,6 +362,7 @@
                     </object>
                     <object class="sizeritem">
                       <object class="wxCalendarBox" name="calException">
+                        <style>wxDP_ALLOWNONE|wxDP_DROPDOWN</style>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>
diff --git a/pgadmin/ui/dlgUser.xrc b/pgadmin/ui/dlgUser.xrc
index 204fbaf..fcbf8c2 100644
--- a/pgadmin/ui/dlgUser.xrc
+++ b/pgadmin/ui/dlgUser.xrc
@@ -92,6 +92,7 @@
                     <growablecols>0</growablecols>
                     <object class="sizeritem">
                       <object class="wxCalendarBox" name="datValidUntil">
+                        <style>wxDP_ALLOWNONE|wxDP_DROPDOWN</style>
                       </object>
                       <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                       <border>4</border>